aboutsummaryrefslogtreecommitdiffstats
path: root/epan/conversation_table.h
diff options
context:
space:
mode:
authorMichael Mann <mmann78@netscape.net>2017-10-29 14:29:27 -0400
committerMichael Mann <mmann78@netscape.net>2017-10-29 20:17:03 +0000
commit63966ec5d5b65cde2297f1f7417d288f884a80b2 (patch)
tree95833a554ec62bac1981ecc6d9a63bd047c735d2 /epan/conversation_table.h
parent765a67b68af28a6dbbb5c79d350896efbaa7adf4 (diff)
Use endpoint_type in conversation tables and hostlists
Follow up to having conversions use endpoint_type instead of port_type. Change-Id: Ifd59a33bd8b9a013c242bce5fcceb09533f02c17 Reviewed-on: https://code.wireshark.org/review/24172 Petri-Dish: Michael Mann <mmann78@netscape.net> Tested-by: Petri Dish Buildbot Reviewed-by: Michael Mann <mmann78@netscape.net>
Diffstat (limited to 'epan/conversation_table.h')
-rw-r--r--epan/conversation_table.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/epan/conversation_table.h b/epan/conversation_table.h
index b71d1a03b4..25f8bbb488 100644
--- a/epan/conversation_table.h
+++ b/epan/conversation_table.h
@@ -26,6 +26,7 @@
#include "conv_id.h"
#include "tap.h"
+#include "conversation.h"
#include "wmem/wmem.h"
#ifdef __cplusplus
@@ -111,7 +112,7 @@ typedef struct _conversation_item_t {
ct_dissector_info_t *dissector_info; /**< conversation information provided by dissector */
address src_address; /**< source address */
address dst_address; /**< destination address */
- port_type ptype; /**< port_type (e.g. PT_TCP) */
+ endpoint_type etype; /**< endpoint_type (e.g. ENDPOINT_TCP) */
guint32 src_port; /**< source port */
guint32 dst_port; /**< destination port */
conv_id_t conv_id; /**< conversation id */
@@ -132,7 +133,7 @@ typedef struct _conversation_item_t {
typedef struct _hostlist_talker_t {
hostlist_dissector_info_t *dissector_info; /**< conversation information provided by dissector */
address myaddress; /**< address */
- port_type ptype; /**< port_type (e.g. PT_TCP) */
+ endpoint_type etype; /**< endpoint_type (e.g. ENDPOINT_TCP) */
guint32 port; /**< port */
guint64 rx_frames; /**< number of received packets */
@@ -256,11 +257,11 @@ WS_DLL_PUBLIC char *get_conversation_address(wmem_allocator_t *allocator, addres
*
* @param allocator The wmem allocator to use when allocating the string
* @param port The port number.
* @param ptype The port type.
* @param resolve_names Enable name resolution.
* @return A string representing the port.
*/
-WS_DLL_PUBLIC char *get_conversation_port(wmem_allocator_t *allocator, guint32 port, port_type ptype, gboolean resolve_names);
+WS_DLL_PUBLIC char *get_conversation_port(wmem_allocator_t *allocator, guint32 port, endpoint_type etype, gboolean resolve_names);
/** Get a display filter for the given conversation and direction.
*
@@ -294,7 +295,7 @@ WS_DLL_PUBLIC char *get_hostlist_filter(hostlist_talker_t *host);
*/
WS_DLL_PUBLIC void add_conversation_table_data(conv_hash_t *ch, const address *src, const address *dst,
guint32 src_port, guint32 dst_port, int num_frames, int num_bytes, nstime_t *ts, nstime_t *abs_ts,
- ct_dissector_info_t *ct_info, port_type ptype);
+ ct_dissector_info_t *ct_info, endpoint_type etype);
/** Add some data to the conversation table, passing a value to be used in
* addition to the address and port quadruple to uniquely identify the
@@ -316,7 +317,7 @@ WS_DLL_PUBLIC void add_conversation_table_data(conv_hash_t *ch, const address *s
WS_DLL_PUBLIC void
add_conversation_table_data_with_conv_id(conv_hash_t *ch, const address *src, const address *dst, guint32 src_port,
guint32 dst_port, conv_id_t conv_id, int num_frames, int num_bytes,
- nstime_t *ts, nstime_t *abs_ts, ct_dissector_info_t *ct_info, port_type ptype);
+ nstime_t *ts, nstime_t *abs_ts, ct_dissector_info_t *ct_info, endpoint_type etype);
/** Add some data to the table.
*
@@ -330,7 +331,7 @@ add_conversation_table_data_with_conv_id(conv_hash_t *ch, const address *src, co
* @param port_type_val the port type (e.g. PT_TCP)
*/
WS_DLL_PUBLIC void add_hostlist_table_data(conv_hash_t *ch, const address *addr,
- guint32 port, gboolean sender, int num_frames, int num_bytes, hostlist_dissector_info_t *host_info, port_type port_type_val);
+ guint32 port, gboolean sender, int num_frames, int num_bytes, hostlist_dissector_info_t *host_info, endpoint_type etype);
#ifdef __cplusplus
}
@@ -256,11 +257,11 @@ WS_DLL_PUBLIC char *get_conversation_address(wmem_allocator_t *allocator, addres
* @param allocator The wmem allocator to use when allocating the string
* @param port The port number.
- * @param ptype The port type.
+ * @param etype The endpoint type.
* @param resolve_names Enable name resolution.
* @return A string representing the port.